@@ -10,23 +10,29 @@ function(obj){
      term.ord <- attr(terms(obj),"order")
      nmain <- length(which(term.ord==1))
      intcol <- attr(attr(mod,"terms"),"intercept")
-     respnam <- colnames(mod)[attr(attr(mod,"terms"),"response")]
+     respcol <- attr(attr(mod,"terms"),"response")
+     respnam <- colnames(mod)[respcol]
      labs <- lapply(vector("list",nmain),function(sp){c("-","+")})
-     xmod <- mod[,rowSums(attr(attr(mod,"terms"),"factors"))>0]
+     xmod <- mod[,-c(intcol,respcol)] #[,rowSums(attr(attr(mod,"terms"),"factors"))>0]
        # numeric -1 1 columns instead of factors 
        # because otherwise prediction difficult for intermediate (0) level
-     if (any(sapply(xmod,"is.factor")) || "aov" %in% class(obj)) {
+  #   if (any(sapply(xmod,"is.factor")) || "aov" %in% class(obj)) {
        hilf <- 0
        for (i in 1:length(xmod)) {
-           hilf <- hilf+1
-           if (is.factor(xmod[[i]])) { 
-              labs[[hilf]] <- levels(xmod[[i]])
-              xmod[[i]] <- 2*(as.numeric(xmod[[i]])-1.5)
+           ## character variables are already factors because of lm object
+           if (is.factor(xmod[[i]])) 
+              labs[[i]] <- levels(xmod[[i]])
+              else labs[[i]] <- range(xmod[[i]])
+              xmod[[i]] <- as.numeric(xmod[[i]])
+              mu <- mean(xmod[[i]])
+              r <- range(xmod[[i]])
+              r <- r[2]-r[1]
+              xmod[[i]] <- 2*(xmod[[i]]-mu)/r
+  #         }
            }
-           }
-       mod[,colnames(xmod)] <- xmod
-       obj <- lm(terms(obj),data=data.frame(mod[,respnam],mod))
-       }
+       mod[,-c(intcol,respcol)] <- xmod
+       obj <- lm(terms(obj),data=data.frame(mod))
+  #     }
        ## return list with linear model for further calculations
        ## and labels for annotating plots
        list(model=obj,labs=labs)
